=======
History
=======

0.1 (2020-05-12)
------------------

* First release on PyPI.
* 0.1.1 - minor fix to __init__.py
* 0.1.2 - bug fix in evolve_expectations
* 0.1.3 - remove min/max parameter check
* 0.1.4 - revised the likelihood calculation for MCMC (now shape and normalization treated separately)

